package moevie.dbtest;

import moevie.db.DataAccessException;
import moevie.db.DataAccessProvider;
import moevie.db.dao.BeoordelingDAO;
import moevie.db.data.Beoordeling;

import java.util.Arrays;
import java.util.Collections;
import java.util.List;

/**
 * Enkele testen die verband houden met het data-access-object voor beoordelingen.
 */
public class BeoordelingDAOTest {

    private DataAccessProvider dap;

    public BeoordelingDAOTest(DataAccessProvider dap) {
        this.dap = dap;
    }

    private void lijstBeoordelingen() {
        List<Beoordeling> lijst = dap.getBeoordelingDAO().lijstBeoordelingen(1);
        assert 2 == lijst.size();

        Beoordeling beoordeling = lijst.get(0);
        assert 1 == beoordeling.getFilm();
        assert 4 == beoordeling.getSterren();
        assert "albert".equals(beoordeling.getGebruiker());
        assert beoordeling.isIngevuld();

        beoordeling = lijst.get(1);
        assert 1 == beoordeling.getFilm();
        assert 3 == beoordeling.getSterren();
        assert "Nogal ouderwets maar OK".equals(beoordeling.getCommentaar());
        assert "aladdin".equals(beoordeling.getGebruiker());
        assert beoordeling.isIngevuld();
    }

    private void lijstBevatEnkelIngevuld() {
        List<Beoordeling> lijst = dap.getBeoordelingDAO().lijstBeoordelingen(2);
        assert 0 == lijst.size();
    }

    private void markeerAlsGezien() {
        BeoordelingDAO dao = dap.getBeoordelingDAO();

        List<Integer> films = Arrays.asList(3, 1, 2);
        dao.markeerAlsGezien("albert", films);

        // film 3 inderdaad gezien?
        Beoordeling beoordeling = dao.getBeoordeling(3, "albert");
        assert beoordeling != null;
        assert 3 == beoordeling.getFilm();
        assert !beoordeling.isIngevuld();

        // geen andere wijzigingen
        assert 2 == dao.lijstBeoordelingen(1).size();

        // beoordeling terug verwijderen opdat andere testen zouden blijven werken
        dao.verwijderBeoordeling(3, "albert");
    }

    private void beoordeelFilm() {
        BeoordelingDAO dao = dap.getBeoordelingDAO();
        dao.nieuweBeoordeling(2, "albert", "Best grappig", 2);

        Beoordeling beoordeling = dao.getBeoordeling(2, "albert");
        assert beoordeling.isIngevuld();
        assert "Best grappig".equals(beoordeling.getCommentaar());
        assert 2 == beoordeling.getSterren();

        // beoordeling terug verwijderen opdat andere testen zouden blijven werken
        dao.verwijderBeoordeling(2, "albert");
        dao.markeerAlsGezien("albert", Collections.singletonList(2));

    }
    private void beoordeelingNietGezieneFilm() {
        BeoordelingDAO dao = dap.getBeoordelingDAO();
        // mag geen effect hebben
        dao.nieuweBeoordeling(2, "aladdin", "Best grappig", 5);
        Beoordeling beoordeling = dao.getBeoordeling(2, "aladdin");
        assert null == beoordeling;
    }

    private void tweedeBeoordeling() {
        // moet een uitzondering genereren
        try {
            dap.getBeoordelingDAO().nieuweBeoordeling(1, "albert", "Best grappig", 5);
            assert false; // mag niet worden uitgevoerd!
        } catch (DataAccessException ex) {
            // we verwachten een uitzondering
            assert true;
        }
    }

    public void run () {
        lijstBeoordelingen();
        lijstBevatEnkelIngevuld();
        markeerAlsGezien();
        beoordeelFilm();
        beoordeelingNietGezieneFilm();
        tweedeBeoordeling();
    }


}
