package moevie.dbtest;

import moevie.db.DataAccessProvider;
import moevie.db.dao.FilmDAO;
import moevie.db.data.Film;

import java.util.List;

/**
 * Enkele testen die verband houden met het data-access-object voor films.
 */
public class FilmDAOTest {

    private DataAccessProvider dap;

    public FilmDAOTest(DataAccessProvider dap) {
        this.dap = dap;
    }

    private void filmGegevens() {
        // we gebruiken met opzet een film die nog door niemand is gezien,
        Film film = dap.getFilmDAO().getFilm(3, "albert");

        assert 3 == film.getId();
        assert "Indiana Jones".equals(film.getTitel());
        assert "Harrison Ford".equals(film.getHoofdrol());
        assert "aladdin".equals(film.getEigenaar());

    }

    private void filmMetSterren() {
        // gezien door gebruiker
        FilmDAO dao = dap.getFilmDAO();
        Film film = dao.getFilm(1, "albert");
        assert 3.5 == film.getSterren();
        assert film.isGezien();

        // niet gezien door gebruiker
        film = dao.getFilm(1, "david");
        assert 3.5 == film.getSterren();
        assert ! film.isGezien();
    }

    private void filmZonderSterren() {
        // wel gezien door iemand
        FilmDAO dao = dap.getFilmDAO();
        Film film = dao.getFilm(2, "albert");
        assert 0.0 == film.getSterren();

        // niet gezien door iemand
        film = dao.getFilm(3, "albert");
        assert 0.0 == film.getSterren();
    }

    private void lijstFilms() {
        List<Film> lijst = dap.getFilmDAO().lijstFilms("aladdin");
        assert 3 == lijst.size();
        assert 3 == lijst.get(0).getId();
        assert ! lijst.get(0).isGezien();
        assert 2 == lijst.get(1).getId();
        assert ! lijst.get(1).isGezien();
        assert 1 == lijst.get(2).getId();
        assert lijst.get(2).isGezien();
    }

    private void nieuweFilm() {
        FilmDAO dao = dap.getFilmDAO();
        int id = dao.nieuweFilm("Titel", "aladdin", "Hoofdrol");

        Film film = dao.getFilm(id, "aladdin");
        assert id== film.getId();
        assert "Titel".equals(film.getTitel());
        assert "Hoofdrol".equals(film.getHoofdrol());
        assert "aladdin".equals(film.getEigenaar());
        assert ! film.isGezien();
        assert 0.0 == film.getSterren();

        // film terug verwijderen opdat andere testen zouden blijven werken
        dao.verwijderFilm(film.getId());
    }
    
    public void run() {
        filmGegevens();
        filmMetSterren();
        filmZonderSterren();
        lijstFilms();
        nieuweFilm();
    }

}
