package moevie.db.dao;

import moevie.db.data.Beoordeling;

import java.util.List;

/**
 * Data-access-object voor beoordelingen
 */
public interface BeoordelingDAO {

    /**
     * Geef een lijst terug van alle beoordelingen voor een bepaalde film. De meest recente beoordeling komt eerst.
     * Wanneer een film door een gebruiker is gezien, maar nog niet van sterren of commentaar is voorzien, dan
     * staat deze 'lege' beoordeling niet in de lijst.
     * @param film Unieke sleutel van de film
     */
    List<Beoordeling> lijstBeoordelingen(int film);

    /**
     * Geef de beoordeling terug van een bepaalde film door een bepaalde gebruiker. Geeft null terug
     * wanneer de film door de gebruiker nog niet is gezien.
     * <p><b>Opgelet!</b> De naam van de gebruiker is niet
     * ingevuld in het resultaat van deze methode.</p>
     * @param film Unieke sleutel van de film
     * @param gebruiker Unieke sleutel van de gebruiker
     */
    Beoordeling getBeoordeling (int film, String gebruiker);

    /**
     * Registreer een aantal films als 'gezien'. Negeert films die voor deze gebruiker
     *  al eerder gemarkeerd zijn.
     * @param gebruiker Unieke sleutel voor de gebruiker
     * @param films Lijst van unieke sleutels van de betreffende films
     */
    void markeerAlsGezien (String gebruiker, List<Integer> films);

    /**
     * Registreer een beoordeling voor deze film. Doet niets wanneer de gebruiker de film
     * nog niet heeft gezien. Gooit een {@link moevie.db.DataAccessException} op als de gebruiker
     * de film reeds eerder beoordeeld heeft.
     * @param film Unieke sleutel van de film
     * @param gebruiker Unieke sleutel van de gebruiker
     * @param commentaar Commentaartekst van de beoordeling
     * @param sterren Aantal toegekende sterren 1,2,3,4 of 5
     */
    void nieuweBeoordeling (int film, String gebruiker, String commentaar, int sterren);

    /**
     * Verwijdert een beoordeling. (Wordt enkel gebruikt bij testen.)
     * @param film Unieke sleutel van de film
     * @param gebruiker Unieke sleutel van de gebruiker
     */
    void verwijderBeoordeling (int film, String gebruiker);
}
