package moevie.db.dao;

import moevie.db.data.Film;

import java.util.List;

/**
 * Data-access-object voor films.
 */
public interface FilmDAO {

    /**
     * Geef de gegevens terug van een bepaalde film, of null wanneer deze film niet bestaat in de databank.
     *
     * @param film      Unieke sleutel waarmee deze film wordt geïdentificeerd
     * @param gebruiker (Unieke sleutel van de) huidige gebruiker. Dient om aan te geven of een film door die gebruiker
     *                  werd gezien of niet.
     */
    Film getFilm(int film, String gebruiker);

    /**
     * Geef een lijst terug van alle films in de database - de meest recente eerst.
     *
     * @param gebruiker (Unieke sleutel van de) huidige gebruiker. Dient om aan te geven of een film door die gebruiker
     *                  werd gezien of niet.
     */
    List<Film> lijstFilms(String gebruiker);

    /**
     * Voeg een nieuwe film toe aan de database.
     *
     * @param titel    Titel van de nieuwe film
     * @param eigenaar Unieke sleutel van de eigenaar
     * @param hoofdrol  Naam van de hoofdrolspeler
     * @return unieke sleutel voor de nieuw aangemaakte film
     */
    int nieuweFilm(String titel, String eigenaar, String hoofdrol);

    /**
     * Verwijder een film uit de database. (Wordt enkel gebruikt bij het testen,)
     * @param film Uniekesleutel waarmee deze film wordt geïdentificeerd
     */
    void verwijderFilm(int film);

}
