package moevie.db.jdbc;

import moevie.db.DataAccessException;
import moevie.db.dao.GebruikerDAO;

import java.sql.*;

/**
 * Implementatie van {@link GebruikerDAO} met behulp van JDBC
 */
class JDBCGebruikerDAO implements GebruikerDAO {

    // Het veld url en de methode getConnection bevinden zich in elke
    // JDBC-DAO. Het zou geen slecht idee zijn om die
    // in een gemeenschappelijke bovenklasse te stoppen in plaats van
    // telkens te knippen en te plakken

    private String url;

    private Connection getConnection() throws SQLException {
        return DriverManager.getConnection(url);
    }

    public JDBCGebruikerDAO(String url) {
        this.url = url;
    }

    @Override
    public boolean findGebruiker(String loginId, String wachtwoord) {
        try (Connection conn = getConnection();
             PreparedStatement ps = conn.prepareStatement(
                     "SELECT 1 FROM Gebruikers WHERE ID = ? AND Wachtwoord = ?"
             )
        ) {
            ps.setString(1, loginId);
            ps.setString(2, wachtwoord);
            try (ResultSet rs = ps.executeQuery()) {
                return rs.next(); // true als er minstens 1 resultaat is, anders false
            }
        } catch (SQLException ex) {
            throw new DataAccessException("findGebruiker", ex);
        }
    }
}
