package controllers;

import moevie.db.data.Beoordeling;
import spark.xtra.Page;

import java.util.ArrayList;
import java.util.List;

/**
 * Bevat actiemethoden voor filmdetails
 */
public class Filmdetail extends MoevieController {

    /**
     * Geef de detailpagina van een film weer met de beoordelingen.
     */
    public Page index() {

        int id = Integer.parseInt(request.params("id"));

        return filmDetailPagina(id)
                .with("aantalSterren", 0) // niet 'blank' want dit moet een getal zijn
                .withBlank("commentaar"); // leeg beoordelingsformulier
    }

    private Page filmDetailPagina(int id) {
        Beoordeling b = DAP.getBeoordelingDAO().getBeoordeling(id, getAangemeldeGebruiker());
        boolean beoordeeld = false;
        if (b != null) {
            beoordeeld = b.isIngevuld();
        }

        return page("film.html")
                .with("film", DAP.getFilmDAO().getFilm(id, getAangemeldeGebruiker()))
                .with("beoordeeldDoorGebruiker", beoordeeld)
                .with("beoordelingen", DAP.getBeoordelingDAO().lijstBeoordelingen(id));
    }

    /**
     * Geef aan dat de huidige gebruiker de opgegeven film heeft gezien
     */
    public Page markeerAlsGezien() {
        int id = Integer.parseInt(request.params("id"));
        List<Integer> gezien = new ArrayList<>();
        gezien.add(id);
        // TODO foutafhandeling
        DAP.getBeoordelingDAO().markeerAlsGezien(getAangemeldeGebruiker(), gezien);
        return redirect("/films/" + id);
    }


    /**
     * Voeg een nieuwe beoordeling toe
     */
    public Page maakBeoordeling() {

        int filmId = Integer.parseInt(request.params("id"));

        String commentaar = request.queryParams("commentaar");
        String aantalSterrenString = request.queryParams("aantalSterren");
        if (commentaar.trim().isEmpty() || aantalSterrenString == null) {
            int aantalSterren;
            if (aantalSterrenString == null) {
                // geeft aan dat er geen enkele radioknop geselecteerd was
                aantalSterren = 0;
            } else {
                aantalSterren = Integer.parseInt(aantalSterrenString);
            }
            return filmDetailPagina(filmId)
                    .with("aantalSterren", aantalSterren)
                    .with("commentaar", commentaar)
                    .with("error", "Sterren en commentaar moeten beiden zijn ingevuld");
        }

        // TODO foutafhandeling
        DAP.getBeoordelingDAO().nieuweBeoordeling(
                filmId,
                getAangemeldeGebruiker(),
                commentaar,
                Integer.parseInt(aantalSterrenString));
        return redirect("/films/" + filmId);

    }

}
